#if defined(__dsPIC30F__)
#include <p30fxxxx.h>
#elif defined(__dsPIC33F__)
#include <p33Fxxxx.h>
#elif defined(__PIC24H__)
#include <p24Hxxxx.h>
#endif

#include "INT.h"

void INT_Config(void)
{
	//SR: Status Register (In CPU)
	//bit 7-5 IPL<2:0>: CPU Interrupt Priority Level Status bits
	//111 = CPU interrupt priority level is 7 (15). User interrupts disabled.
	//110 = CPU interrupt priority level is 6 (14)
	//101 = CPU interrupt priority level is 5 (13)
	//100 = CPU interrupt priority level is 4 (12)
	//011 = CPU interrupt priority level is 3 (11)
	//010 = CPU interrupt priority level is 2 (10)
	//001 = CPU interrupt priority level is 1 (9)
	//000 = CPU interrupt priority level is 0 (8)
	SRbits.IPL=0;//CPU Interrupt Priority Level

	//CORCON: Core Control Register
	//bit 3 IPL3: CPU Interrupt Priority Level Status bit 3
	//1 = CPU interrupt priority level is greater than 7
	//0 = CPU interrupt priority level is 7 or less
	//Note 1: The IPL3 bit is concatenated with the IPL<2:0> bits (SR<7:5>) to form the CPU interrupt priority
	//level.
	//Note: Can only read and clear.
	CORCONbits.IPL3=0;

	//INTCON1: Interrupt Control Register 1
	//bit 1 OSCFAIL: Oscillator Failure Trap Status bit
	//1 = Oscillator failure trap has occurred
	//0 = Oscillator failure trap has not occurred
	//bit 0 Unimplemented: Read as 0
	INTCON1bits.OSCFAIL=0;
	//bit 2 STKERR: Stack Error Trap Status bit
	//1 = Stack error trap has occurred
	//0 = Stack error trap has not occurred
	INTCON1bits.STKERR=0;
	//bit 3 ADDRERR: Address Error Trap Status bit
	//1 = Address error trap has occurred
	//0 = Address error trap has not occurred
	INTCON1bits.ADDRERR=0;
	//bit 4 MATHERR: Arithmetic Error Status bit
	//1 = Overflow trap has occurred
	//0 = Overflow trap has not occurred
	INTCON1bits.MATHERR=0;
	//bit 7-5 Unimplemented: Read as 0
	//bit 8 COVTE: Catastrophic Overflow Trap Enable bit
	//1 = Trap on catastrophic overflow of Accumulator A or B enabled
	//0 = Trap disabled
	INTCON1bits.COVTE=0;
	//bit 9 OVBTE: Accumulator B Overflow Trap Enable bit
	//1 = Trap overflow of Accumulator B
	//0 = Trap disabled
	INTCON1bits.OVBTE=0;
	//bit 10 OVATE: Accumulator A Overflow Trap Enable bit
	//1 = Trap overflow of Accumulator A
	//0 = Trap disabled
	INTCON1bits.OVATE=0;
	//bit 14-11 Unimplemented: Read as 0
	//bit 15 NSTDIS: Interrupt Nesting Disable bit
	//1 = Interrupt nesting is disabled
	//0 = Interrupt nesting is enabled
	INTCON1bits.NSTDIS=0;

	//INTCON2: Interrupt Control Register 2
	//bit 0 INT0EP: External Interrupt #0 Edge Detect Polarity Select bit
	//1 = Interrupt on negative edge
	//0 = Interrupt on positive edge
	INTCON2bits.INT0EP=0;
	//bit 1 INT1EP: External Interrupt #1 Edge Detect Polarity Select bit
	//1 = Interrupt on negative edge
	//0 = Interrupt on positive edge
	INTCON2bits.INT1EP=0;
	//bit 2 INT2EP: External Interrupt #2 Edge Detect Polarity Select bit
	//1 = Interrupt on negative edge
	//0 = Interrupt on positive edge
	INTCON2bits.INT2EP=0;
	//bit 3 INT3EP: External Interrupt #3 Edge Detect Polarity Select bit
	//1 = Interrupt on negative edge
	//0 = Interrupt on positive edge
	//bit 4 INT4EP: External Interrupt #4 Edge Detect Polarity Select bit
	//1 = Interrupt on negative edge
	//0 = Interrupt on positive edge
	//bit 13-5 Unimplemented: Read as 0
	//bit 14 DISI: DISI Instruction Status bit
	//1 = DISI instruction is active
	//0 = DISI is not active
	//Note:Read only
	//INTCON2bits.DISI
	//bit 15 ALTIVT: Enable Alternate Interrupt Vector Table bit
	//1 = Use alternate vector table
	//0 = Use standard (default) vector table
	INTCON2bits.ALTIVT=0;

	//IEC0: Interrupt Enable Control Register 0
	//bit 0 INT0IE: External Interrupt 0 Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.INT0IE	=0;
	//bit 1 IC1IE: Input Capture Channel 1 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.IC1IE  =0;
	//bit 2 OC1IE: Output Compare Channel 1 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.OC1IE  =0;
	//bit 3 T1IE: Timer1 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.T1IE   =1;
	//bit 4 IC2IE: Input Capture Channel 2 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.IC2IE  =0;
	//bit 5 OC2IE: Output Compare Channel 2 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.OC2IE  =0;
	//bit 6 T2IE: Timer2 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.T2IE   =0;
	//bit 7 T3IE: Timer3 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.T3IE   =0;
	//bit 8 SPI1IE: SPI1 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.SPI1IE =0;
	//bit 9 U1RXIE: UART1 Receiver Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.U1RXIE =1;
	//bit 10 U1TXIE: UART1 Transmitter Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.U1TXIE =0;
	//bit 11 ADIE: A/D Conversion Complete Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.ADIE   =1;
	//bit 12 NVMIE: Non-Volatile Memory Write Complete Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.NVMIE  =0;
	//bit 13 SI2CIE: I2C Transfer Complete Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.SI2CIE  =0;
	//bit 14 MI2CIE: I2C Bus Collision Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.MI2CIE  =0;
	//bit 15 CNIE: Input Change Notification Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC0bits.CNIE   =0;

	//IEC1: Interrupt Enable Control Register 1
	//bit 0 INT1IE: External Interrupt 1 Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.INT1IE =0;
	//bit 1 IC7IE: Input Capture Channel 7 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.IC7IE  =0;
	//bit 2 IC8IE: Input Capture Channel 8 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.IC8IE  =0;
	//bit 3 OC3IE: Output Compare Channel 3 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.OC3IE  =0;
	//bit 4 OC4IE: Output Compare Channel 4 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.OC4IE  =0;
	//bit 5 T4IE: Timer4 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.T4IE   =0;
	//bit 6 T5IE: Timer5 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.T5IE   =0;
	//bit 7 INT2IE: External Interrupt 2 Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.INT2IE =0;
	//bit 8 U2RXIE: UART2 Receiver Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.U2RXIE =0;
	//bit 9 U2TXIE: UART2 Transmitter Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.U2TXIE =0;
	//bit 10 SPI2IE: SPI2 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 15 IC6IE: Input Capture Channel 6 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 14 IC5IE: Input Capture Channel 5 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 13 IC4IE: Input Capture Channel 4 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 12 IC3IE: Input Capture Channel 3 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 11 C1IE: CAN1 (Combined) Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC1bits.C1IE   =0;

	//IEC2: Interrupt Enable Control Register 2
	//bit 0 OC5IE: Output Compare Channel 5 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 1 OC6IE: Output Compare Channel 6 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 2 OC7IE: Output Compare Channel 7 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 3 OC8IE: Output Compare Channel 8 Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 4 INT3IE: External Interrupt 3 Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 5 INT4IE: External Interrupt 4 Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 6 C2IE: CAN2 (Combined) Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 7 PWMIE: Motor Control Pulse Width Modulation Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 8 QEIIE: Quadrature Encoder Interface Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 9 DCIIE: Data Converter Interface Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC2bits.DCIIE=0;
	//bit 10 LVDIE: Programmable Low Voltage Detect Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	IEC2bits.LVDIE=0;
	//bit 11 FLTAIE: Fault A Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 12 FLTBIE: Fault B Input Interrupt Enable bit
	//1 = Interrupt request enabled
	//0 = Interrupt request not enabled
	//bit 15-13 Unimplemented: Read as 0

	//IPC0: Interrupt Priority Control Register 0
	//bit 15 Unimplemented: Read as 0
	//bit 14-12 T1IP<2:0>: Timer1 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC0bits.T1IP=1;
	//bit 11 Unimplemented: Read as 0
	//bit 10-8 OC1IP<2:0>: Output Compare Channel 1 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC0bits.OC1IP=0;
	//bit 7 Unimplemented: Read as 0
	//bit 6-4 IC1IP<2:0>: Input Capture Channel 1 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC0bits.IC1IP=0;
	//bit 3 Unimplemented: Read as 0
	//bit 2-0 INT0IP<2:0>: External Interrupt 0 Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
  	IPC0bits.INT0IP=0;

	//IPC1: Interrupt Priority Control Register 1
	//bit 15 Unimplemented: Read as 0
	//bit 14-12 T3IP<2:0>: Timer3 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC1bits.T3IP=0;
	//bit 11 Unimplemented: Read as 0
	//bit 10-8 T2IP<2:0>: Timer2 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC1bits.T2IP=0; 
	//bit 7 Unimplemented: Read as 0
	//bit 6-4 OC2IP<2:0>: Output Compare Channel 2 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC1bits.OC2IP=0;
	//bit 3 Unimplemented: Read as 0
	//bit 2-0 IC2IP<2:0>: Input Capture Channel 2 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC1bits.IC2IP=0;

	//IPC2: Interrupt Priority Control Register 2
	//bit 15 Unimplemented: Read as 0
	//bit 14-12 ADIP<2:0>: A/D Conversion Complete Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC2bits.ADIP  =1;
	//bit 11 Unimplemented: Read as 0
	//bit 10-8 U1TXIP<0>: UART1 Transmitter Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC2bits.U1TXIP=1;
	//bit 7 Unimplemented: Read as 0
	//bit 6-4 U1RXIP<2:0>: UART1 Receiver Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC2bits.U1RXIP=1;
	//bit 3 Unimplemented: Read as 0
	//bit 2-0 SPI1IP<2:0>: SPI1 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC2bits.SPI1IP=0;

	//IPC3: Interrupt Priority Control Register 3
	//bit 15 Unimplemented: Read as 0
	//bit 14-12 CNIP<2:0>: Input Change Notification Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC3bits.CNIP  =0;
	//bit 11 Unimplemented: Read as 0
	//bit 10-8 MI2CIP<2:0>: I2C Bus Collision Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC3bits.MI2CIP =0;
	//bit 7 Unimplemented: Read as 0
	//bit 6-4 SI2CIP<2:0>: I2C Transfer Complete Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC3bits.SI2CIP =0;
	//bit 3 Unimplemented: Read as 0
	//bit 2-0 NVMIP<2:0>: Non-Volatile Memory Write Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC3bits.NVMIP =0;

	//IPC4: Interrupt Priority Control Register 4
	//bit 15 Unimplemented: Read as 0
	//bit 14-12 OC3IP<2:0>: Output Compare Channel 3 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC4bits.OC3IP =0;
	//bit 11 Unimplemented: Read as 0
	//bit 10-8 IC8IP<2:0>: Input Capture Channel 8 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC4bits.IC8IP =0;
	//bit 7 Unimplemented: Read as 0
	//bit 6-4 IC7IP<2:0>: Input Capture Channel 7 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC4bits.IC7IP =0;
	//bit 3 Unimplemented: Read as 0
	//bit 2-0 INT1IP<2:0>: External Interrupt 1 Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC4bits.INT1IP=0;

	//IPC5: Interrupt Priority Control Register 5
	//bit 15 Unimplemented: Read as 0
	//bit 14-12 INT2IP<2:0>: External Interrupt 2 Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC5bits.INT2IP=0;
	//bit 11 Unimplemented: Read as 0
	//bit 10-8 T5IP<2:0>: Timer5 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC5bits.T5IP  =0;
	//bit 7 Unimplemented: Read as 0
	//bit 6-4 T4IP<2:0>: Timer4 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC5bits.T4IP  =0;
	//bit 3 Unimplemented: Read as 0
	//bit 2-0 OC4IP<2:0>: Output Compare Channel 4 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC5bits.OC4IP =0;
	
	//IPC6: Interrupt Priority Control Register 6
	//bit 15 Unimplemented: Read as 0
	//bit 14-12 C1IP<2:0>: CAN1 (Combined) Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC6bits.C1IP  =0;
	//bit 11 Unimplemented: Read as 0
	//bit 10-8 SPI2IP<2:0>: SPI2 Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	//bit 7 Unimplemented: Read as 0
	//bit 6-4 U2TXIP<2:0>: UART2 Transmitter Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC6bits.U2TXIP=0;
	//bit 3 Unimplemented: Read as 0
	//bit 2-0 U2RXIP<2:0>: UART2 Receiver Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC6bits.U2RXIP=0;

	//IPC10: Interrupt Priority Control Register 10
	//bit 15 Unimplemented: Read as 0
	//bit 14-12 FLTAIP<2:0>: Fault A Input Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	//bit 11 Unimplemented: Read as 0
	//bit 10-8 LVDIP<2:0>: Programmable Low Voltage Detect Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC10bits.LVDIP =0;	
	//bit 7 Unimplemented: Read as 0
	//bit 6-4 DCIIP<2:0>: Data Converter Interface Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
	IPC10bits.DCIIP =0;
	//bit 3 Unimplemented: Read as 0
	//bit 2-0 QEIIP<2:0>: Quadrature Encoder Interface Interrupt Priority bits
	//001-111 = Interrupt is priority 1-7
	//000 = Interrupt source is disabled
}
