#if defined(__dsPIC30F__)
#include <p30fxxxx.h>
#elif defined(__dsPIC33F__)
#include <p33Fxxxx.h>
#elif defined(__PIC24H__)
#include <p24Hxxxx.h>
#endif

#include "SPI1.h"
#include "INT.h"

void SPI1_Config(void)
{
	//SPIxSTAT: SPI Status and Control Register
	//bit 15 SPIEN: SPI Enable bit
		//1 = Enables module and configures SCKx, SDOx, SDIx and SSx as serial port pins
		//0 = Disables module
	SPI1STATbits.SPIEN=0;
	//bit 14 Unimplemented: Read as 0
	//bit 13 SPISIDL: Stop in Idle Mode bit
		//1 = Discontinue module operation when device enters Idle mode
		//0 = Continue module operation in Idle mode
	SPI1STATbits.SPISIDL=0;
	//bit 12-7 Unimplemented: Read as 0
	//bit 6 SPIROV: Receive Overflow Flag bit
		//1 = A new byte/word is completely received and discarded. The user software has not read the previous data in the SPIxBUF register.
		//0 = No overflow has occurred
	SPI1STATbits.SPIROV=0;
	//bit 5-2 Unimplemented: Read as 0
	//bit 1 SPITBF: SPI Transmit Buffer Full Status bit(Read Only)
		//1 = Transmit not yet started, SPIxTXB is full
		//0 = Transmit started, SPIxTXB is empty
		//Automatically set in hardware when CPU writes SPIxBUF location, loading SPIxTXB.
		//Automatically cleared in hardware when SPIx module transfers data from SPIxTXB to SPIxSR.
	SPI1STATbits.SPITBF=0;
	//bit 0 SPIRBF: SPI Receive Buffer Full Status bit(Read Only)
		//1 = Receive complete, SPIxRXB is full
		//0 = Receive is not complete, SPIxRXB is empty
		//Automatically set in hardware when SPIx transfers data from SPIxSR to SPIxRXB.
		//Automatically cleared in hardware when core reads SPIxBUF location, reading SPIxRXB.
	SPI1STATbits.SPIRBF=0;

	//SPIXCON: SPIx Control Register
	//bit 15 Unimplemented: Read as 0
	//bit 14 FRMEN: Framed SPI Support bit
		//1 = Framed SPI support enabled
		//0 = Framed SPI support disabled
	SPI1CONbits.FRMEN=0;
	//bit 13 SPIFSD: Frame Sync Pulse Direction Control on SSx pin bit
		//1 = Frame sync pulse input (slave)
		//0 = Frame sync pulse output (master)
	SPI1CONbits.SPIFSD=0;
	//bit 12 Unimplemented: Read as 0
	//bit 11 DISSDO: Disable SDOx pin bit
		//1 = SDOx pin is not used by module. Pin is controlled by associated port register.
		//0 = SDOx pin is controlled by the module
	SPI1CONbits.DISSDO=0;
	//bit 10 MODE16: Word/Byte Communication Select bit
		//1 = Communication is word-wide (16 bits)
		//0 = Communication is byte-wide (8 bits)
	SPI1CONbits.MODE16=0;
	//bit 9 SMP: SPI Data Input Sample Phase bit
	//Master mode:
		//1 = Input data sampled at end of data output time
		//0 = Input data sampled at middle of data output time
	//Slave mode:
		//SMP must be cleared when SPI is used in Slave mode.
	SPI1CONbits.SMP=0;
	//bit 8 CKE: SPI Clock Edge Select bit
		//1 = Serial output data changes on transition from active clock state to Idle clock state (see bit 6)
		//0 = Serial output data changes on transition from Idle clock state to active clock state (see bit 6)
		//Note: The CKE bit is not used in the Framed SPI modes. The user should program this bit to 0 for the Framed SPI modes (FRMEN = 1).
	SPI1CONbits.CKE=0;
	//bit 7 SSEN: Slave Select Enable (Slave mode) bit
		//1 = SS pin used for Slave mode
		//0 = SS pin not used by module. Pin controlled by port function.
	SPI1CONbits.SSEN=0;
	//bit 6 CKP: Clock Polarity Select bit
		//1 = Idle state for clock is a high level; active state is a low level
		//0 = Idle state for clock is a low level; active state is a high level
	SPI1CONbits.CKP=0;
	//bit 5 MSTEN: Master Mode Enable bit
		//1 = Master mode
		//0 = Slave mode
	SPI1CONbits.MSTEN=0;
	//bit 4-2 SPRE<2:0>: Secondary Prescale (Master Mode) bits
		//(Supported settings: 1:1, 2:1 through 8:1, all inclusive)
		//111 = Secondary prescale 1:1
		//110 = Secondary prescale 2:1
		//...
		//000 = Secondary prescale 8:1
	SPI1CONbits.SPRE=0;
	//bit 1-0 PPRE<1:0>: Primary Prescale (Master Mode) bits
		//11 = Primary prescale 1:1
		//10 = Primary prescale 4:1
		//01 = Primary prescale 16:1
		//00 = Primary prescale 64:1
	SPI1CONbits.PPRE=0;

	IFS0bits.SPI1IF=0;
	SPI1BUF=0;
}

void _INT_ServiceRoutine _SPI1Interrupt(void)
{	
	IFS0bits.SPI1IF=0;
}

