#if defined(__dsPIC30F__)
#include <p30fxxxx.h>
#elif defined(__dsPIC33F__)
#include <p33Fxxxx.h>
#elif defined(__PIC24H__)
#include <p24Hxxxx.h>
#endif

#include "TMR1.h"
#include "INT.h"

void TMR1_Config(void)
{
	//TxCON: Type A Time Base Register
	//bit 15 TON: Timer On Control bit
		//1 = Starts the timer
		//0 = Stops the timer
	T1CONbits.TON=0;
	//bit 14 Unimplemented: Read as 0
	//bit 13 TSIDL: Stop in Idle Mode bit
		//1 = Discontinue timer operation when device enters Idle mode
		//0 = Continue timer operation in Idle mode
	T1CONbits.TSIDL=0;
	//bit 12-7 Unimplemented: Read as 0
	//bit 6 TGATE: Timer Gated Time Accumulation Enable bit
		//1 = Gated time accumulation enabled
		//0 = Gated time accumulation disabled
		//(TCS must be set to 0 when TGATE = 1. Reads as 0 if TCS = 1)
	T1CONbits.TGATE=0;
	//bit 5-4 TCKPS<1:0>: Timer Input Clock Prescale Select bits
		//11 = 1:256 prescale value
		//10 = 1:64 prescale value
		//01 = 1:8 prescale value
		//00 = 1:1 prescale value
	T1CONbits.TCKPS=0b01;
	//bit 3 Unimplemented: Read as 0
	//bit 2 TSYNC: Timer External Clock Input Synchronization Select bit
		//When TCS = 1:
			//1 = Synchronize external clock input
			//0 = Do not synchronize external clock input
		//When TCS = 0:
			//This bit is ignored. Read as 0. Timer1 uses the internal clock when TCS = 0.
	T1CONbits.TSYNC=0;
	//bit 1 TCS: Timer Clock Source Select bit
		//1 = External clock from pin TxCK
		//0 = Internal clock (FOSC/4)
	T1CONbits.TCS=0;
	//bit 0 Unimplemented: Read as 0

	TMR1=0;
	PR1=3125*4;

	IFS0bits.T1IF=0;

	//bit 15 TON: Timer On Control bit
		//1 = Starts the timer
		//0 = Stops the timer
	T1CONbits.TON=1;
}

void _INT_ServiceRoutine _T1Interrupt(void)
{
	IFS0bits.T1IF=0;
	TMR1=0;
	PR1=3125*4;
	IEC0bits.U1TXIE=1;
	U1TXREG='s';
	LATCbits.LATC13++;
}
