#if defined(__dsPIC30F__)
#include <p30fxxxx.h>
#elif defined(__dsPIC33F__)
#include <p33Fxxxx.h>
#elif defined(__PIC24H__)
#include <p24Hxxxx.h>
#endif

#include "TMR23.h"
#include "INT.h"

void TMR23_Config(void)
{
	//TxCON: Type B Time Base Register
	//bit 15 TON: Timer On bit
		//When T32 = 1 (in 32-bit Timer mode):
			//1 = Starts 32-bit TMRx:TMRy timer pair
			//0 = Stops 32-bit TMRx:TMRy timer pair
		//When T32 = 0 (in 16-bit Timer mode):
			//1 = Starts 16-bit timer
			//0 = Stops 16-bit timer
	T2CONbits.TON=0;
	//bit 14 Unimplemented: Read as 0
	//bit 13 TSIDL: Stop in Idle Mode bit
		//1 = Discontinue timer operation when device enters Idle mode
		//0 = Continue timer operation in Idle mode
	T2CONbits.TSIDL=0;
	//bit 12-7 Unimplemented: Read as 0
	//bit 6 TGATE: Timer Gated Time Accumulation Enable bit
		//1 = Timer gated time accumulation enabled
		//0 = Timer gated time accumulation disabled
		//(TCS must be set to logic 0 when TGATE = 1)
	T2CONbits.TGATE=0;
	//bit 5-4 TCKPS<1:0>: Timer Input Clock Prescale Select bits
		//11 = 1:256 prescale value
		//10 = 1:64 prescale value
		//01 = 1:8 prescale value
		//00 = 1:1 prescale value
	T2CONbits.TCKPS=0;
	//bit 3 T32: 32-bit Timer Mode Select bits
		//1 = TMRx and TMRy form a 32-bit timer
		//0 = TMRx and TMRy form separate 16-bit timer
	T2CONbits.T32=0;
	//bit 2 Unimplemented: Read as 0
	//bit 1 TCS: Timer Clock Source Select bit
		//1 = External clock from pin TxCK
		//0 = Internal clock (FOSC/4)
	T2CONbits.TCS=0;
	//bit 0 Unimplemented: Read as 0

	//TxCON: Type C Time Base Register
	//bit 15 TON: Timer On bit
		//1 = Starts 16-bit TMRx
		//0 = Stops 16-bit TMRx
	T3CONbits.TON=0;
	//bit 14 Unimplemented: Read as 0
	//bit 13 TSIDL: Stop in Idle Mode bit
		//1 = Discontinue module operation when device enters Idle mode
		//0 = Continue module operation in Idle mode
	T3CONbits.TSIDL=0;
	//bit 12-7 Unimplemented: Read as 0
	//bit 6 TGATE: Timer Gated Time Accumulation Enable bit
		//1 = Timer gated time accumulation enabled
		//0 = Timer gated time accumulation disabled (Read as 0 if TCS = 1)
		//(TCS must be set to logic 0 when TGATE = 1)
	T3CONbits.TGATE=0;
	//bit 5-4 TCKPS<1:0>: Timer Input Clock Prescale Select bits
		//11 = 1:256 prescale value
		//10 = 1:64 prescale value
		//01 = 1:8 prescale value
		//00 = 1:1 prescale value
	T3CONbits.TCKPS=0;
	//bit 3-2 Unimplemented: Read as 0
	//bit 1 TCS: Timer Clock Source Select bit
		//1 = External clock from pin TxCK
		//0 = Internal clock (FOSC/4)
	T3CONbits.TCS=0;
	//bit 0 Unimplemented: Read as 0

	TMR2=0;
	PR2=0;
	IFS0bits.T2IF=0;

	TMR3=0;
	PR3=0;
	TMR3HLD=0;
	IFS0bits.T3IF=0;

	//TxCON: Type B Time Base Register
	//bit 15 TON: Timer On bit
		//When T32 = 1 (in 32-bit Timer mode):
			//1 = Starts 32-bit TMRx:TMRy timer pair
			//0 = Stops 32-bit TMRx:TMRy timer pair
		//When T32 = 0 (in 16-bit Timer mode):
			//1 = Starts 16-bit timer
			//0 = Stops 16-bit timer
	T2CONbits.TON=0;
	//TxCON: Type C Time Base Register
	//bit 15 TON: Timer On bit
		//1 = Starts 16-bit TMRx
		//0 = Stops 16-bit TMRx
	T3CONbits.TON=0;
}

void _INT_ServiceRoutine _T2Interrupt(void)
{
	IFS0bits.T2IF=0;
}

void _INT_ServiceRoutine _T3Interrupt(void)
{
	IFS0bits.T3IF=0;
}
