#if defined(__dsPIC30F__)
#include <p30fxxxx.h>
#elif defined(__dsPIC33F__)
#include <p33Fxxxx.h>
#elif defined(__PIC24H__)
#include <p24Hxxxx.h>
#endif

#include "UART1.h"
#include "INT.h"
#include "control.h"

void UART1_Config(void)
{
	//UXMODE: UARTX Mode Register
	//bit 15 UARTEN: UART Enable bit
		//1 = UART is enabled. UART pins are controlled by UART as defined by UEN<1:0> and UTXEN control bits.
		//0 = UART is disabled. UART pins are controlled by corresponding PORT, LAT, and TRIS bits.
	U1MODEbits.UARTEN=1;
	//bit 14 Unimplemented: Read as 0
	//bit 13 USIDL: Stop in Idle Mode bit
		//1 = Discontinue operation when device enters Idle mode
		//0 = Continue operation in Idle mode
	U1MODEbits.USIDL=0;
	//bit 12 Unimplemented: Read as 0
	//bit 11 Reserved: Write 0 to this location
	//bit 10 ALTIO: UART Alternate I/O Selection bit
		//1 = UART communicates using UxATX and UxARX I/O pins
		//0 = UART communicates using UxTX and UxRX I/O pins
		//Note: The alternate UART I/O pins are not available on all devices. See device data sheet for details.
	U1MODEbits.ALTIO=0;
	//bit 9-8 Reserved: Write 0 to these locations
	//bit 7 WAKE: Enable Wake-up on Start bit Detect During Sleep Mode bit
		//1 = Wake-up enabled
		//0 = Wake-up disabled
	U1MODEbits.WAKE=0;
	//bit 6 LPBACK: UART Loopback Mode Select bit
		//1 = Enable Loopback mode
		//0 = Loopback mode is disabled
	U1MODEbits.LPBACK=0;
	//bit 5 ABAUD: Auto Baud Enable bit
		//1 = Input to Capture module from UxRX pin
		//0 = Input to Capture module from ICx pin
	U1MODEbits.ABAUD=0;
	//bit 4-3 Unimplemented: Read as 0
	//bit 2-1 PDSEL<1:0>: Parity and Data Selection bits
		//11 = 9-bit data, no parity
		//10 = 8-bit data, odd parity
		//01 = 8-bit data, even parity
		//00 = 8-bit data, no parity
	U1MODEbits.PDSEL=0;
	//bit 0 STSEL: Stop Selection bit
		//1 = 2 Stop bits
		//0 = 1 Stop bit
	U1MODEbits.STSEL=0;

	//UXSTA: UARTX Status and Control Register
	//bit 15 UTXISEL: Transmission Interrupt Mode Selection bit
		//1 = Interrupt when a character is transferred to the Transmit Shift register and as result, the transmit buffer becomes empty
		//0 = Interrupt when a character is transferred to the Transmit Shift register (this implies that there is at least one character open in the transmit buffer)
	U1STAbits.UTXISEL=0;
	//bit 14-12 Unimplemented: Read as 0
	//bit 11 UTXBRK: Transmit Break bit
		//1 = UxTX pin is driven low, regardless of transmitter state
		//0 = UxTX pin operates normally
	U1STAbits.UTXBRK=0;
	//bit 10 UTXEN: Transmit Enable bit
		//1 = UART transmitter enabled, UxTX pin controlled by UART (if UARTEN = 1)
		//0 = UART transmitter disabled, any pending transmission is aborted and buffer is reset. UxTX pin controlled by PORT.
	U1STAbits.UTXEN=1;
	//bit 9 UTXBF: Transmit Buffer Full Status bit (Read Only)
		//1 = Transmit buffer is full
		//0 = Transmit buffer is not full, at least one more data word can be written
	//U1STAbits.UTXBF;
	//bit 8 TRMT: Transmit Shift Register is Empty bit (Read Only)
		//1 = Transmit shift register is empty and transmit buffer is empty (the last transmission has completed)
		//0 = Transmit shift register is not empty, a transmission is in progress or queued in the transmit buffer
	//U1STAbits.TRMT;
	//bit 7-6 URXISEL<1:0>: Receive Interrupt Mode Selection bit
		//11 =Interrupt flag bit is set when Receive Buffer is full (i.e., has 4 data characters)
		//10 =Interrupt flag bit is set when Receive Buffer is 3/4 full (i.e., has 3 data characters)
		//0x =Interrupt flag bit is set when a character is received
	U1STAbits.URXISEL=0;
	//bit 5 ADDEN: Address Character Detect (bit 8 of received data = 1)
		//1 = Address Detect mode enabled. If 9-bit mode is not selected, this control bit has no effect.
		//0 = Address Detect mode disabled
	U1STAbits.ADDEN=0;
	//bit 4 RIDLE: Receiver Idle bit (Read Only)
		//1 = Receiver is Idle
		//0 = Data is being received
	//U1STAbits.RIDLE;
	//bit 3 PERR: Parity Error Status bit (Read Only)
		//1 = Parity error has been detected for the current character
		//0 = Parity error has not been detected
	//U1STAbits.PERR;
	//bit 2 FERR: Framing Error Status bit (Read Only)
		//1 = Framing Error has been detected for the current character
		//0 = Framing Error has not been detected
	//U1STAbits.FERR;
	//bit 1 OERR: Receive Buffer Overrun Error Status bit (Read/Clear Only)
		//1 = Receive buffer has overflowed
		//0 = Receive buffer has not overflowed
	U1STAbits.OERR=0;
	//bit 0 URXDA: Receive Buffer Data Available bit (Read Only)
		//1 = Receive buffer has data, at least one more character can be read
		//0 = Receive buffer is empty
	//U1STAbits.URXDA;
	
	U1BRG=3;

	IFS0bits.U1TXIF=0;
	U1TXREG=0;
	IFS0bits.U1RXIF=0;
	//U1RXREG;
}

void _INT_ServiceRoutine _U1RXInterrupt(void)
{
	IFS0bits.U1RXIF=0;
	//U1TXREG=U1RXREG;
}
void _INT_ServiceRoutine _U1TXInterrupt(void)
{
	static unsigned char sensor=0;
	static unsigned char emitter=0;
	static unsigned char highbyte=0;
	unsigned char done;
	
	IFS0bits.U1TXIF=0;

	done=0;
	while(done==0)
	{
		if(emitter<8)
		{
			if(sensor<8)
			{
				if(highbyte<2)
				{
					U1TXREG=ReadValue(sensor,emitter,highbyte);
					highbyte++;
					done=1;
				}
				else
				{
					highbyte=0;
					sensor++;
				}
			}
			else
			{
				sensor=0;
				emitter++;
			}
		}
		else
		{
			emitter=0;
			U1TXREG='f';
			IEC0bits.U1TXIE=0;
			done=1;
		}
	}
}
