#if defined(__dsPIC30F__)
#include <p30fxxxx.h>
#elif defined(__dsPIC33F__)
#include <p33Fxxxx.h>
#elif defined(__PIC24H__)
#include <p24Hxxxx.h>
#endif

#include "control.h"

#define NUMSENSORS 8
#define NUMEMITTERS 8

static unsigned int AnalogValue[NUMEMITTERS][NUMSENSORS];
static unsigned int* AnalogChannel[NUMSENSORS];

void Control_Init(void)
{
	unsigned char sensor,emitter;

	TRISDbits.TRISD0=0;
	TRISDbits.TRISD1=0;
	TRISFbits.TRISF0=0;
	TRISFbits.TRISF1=0;
	TRISFbits.TRISF4=0;
	TRISFbits.TRISF5=0;
	TRISFbits.TRISF6=0;
	TRISDbits.TRISD8=0;

	Control_EmittersOff();

	AnalogChannel[0]=(unsigned int*)&ADCBUF0;
	AnalogChannel[1]=(unsigned int*)&ADCBUF1;
	AnalogChannel[2]=(unsigned int*)&ADCBUF2;
	AnalogChannel[3]=(unsigned int*)&ADCBUF3;
	AnalogChannel[4]=(unsigned int*)&ADCBUF4;
	AnalogChannel[5]=(unsigned int*)&ADCBUF5;
	AnalogChannel[6]=(unsigned int*)&ADCBUF6;
	AnalogChannel[7]=(unsigned int*)&ADCBUF7;
	for(emitter=0;emitter<NUMEMITTERS;emitter++)
	{
		for(sensor=0;sensor<NUMSENSORS;sensor++)
		{
			AnalogValue[emitter][sensor]=0;
		}
	}
}

void UpdateEmitterValues(unsigned char emitter)
{
	unsigned int sensor;
	for(sensor=0;sensor<NUMSENSORS;sensor++)
	{
		AnalogValue[emitter][sensor]= *(AnalogChannel[sensor]);
	}
	sensor=0;
}

unsigned char ReadValue(unsigned char sensor,unsigned char emitter,unsigned char highbyte)
{	
	unsigned int valueint;
	unsigned char* pointer1;
	unsigned char valuechar;
	if(sensor<NUMSENSORS)
	{
		if(emitter<NUMEMITTERS)
		{
			if(highbyte<2)
			{
				valueint=AnalogValue[emitter][sensor];
				pointer1=(unsigned char*)&valueint;
				pointer1+=highbyte;
				valuechar=*pointer1;
				return valuechar;
			}
		}
	}
	return 0;
}

void Control_EmittersOff(void)
{
	LATDbits.LATD0=1;
	LATDbits.LATD1=1;
	LATFbits.LATF0=1;
	LATFbits.LATF1=1;
	LATFbits.LATF4=1;
	LATFbits.LATF5=1;
	LATFbits.LATF6=1;
	LATDbits.LATD8=1;
}

void Control_EmittersOn(void)
{
	LATDbits.LATD0=0;
	LATDbits.LATD1=0;
	LATFbits.LATF0=0;
	LATFbits.LATF1=0;
	LATFbits.LATF4=0;
	LATFbits.LATF5=0;
	LATFbits.LATF6=0;
	LATDbits.LATD8=0;
}

void Control_SingleEmitterOn(unsigned char emitter)
{
	Control_EmittersOff();
	switch(emitter)
	{
		case 0:		LATDbits.LATD0=0;
					break;
		case 1:		LATDbits.LATD1=0;
					break;
		case 2:		LATFbits.LATF0=0;
					break;
		case 3:		LATFbits.LATF1=0;
					break;
		case 4:		LATFbits.LATF4=0;
					break;
		case 5:		LATFbits.LATF5=0;
					break;
		case 6:		LATFbits.LATF6=0;
					break;
		case 7:		LATDbits.LATD8=0;
					break;
		default: 	break;		
	}
}
